==> Authomatic-0.0.6.tar.gz: Authomatic-0.0.6/examples/gae/tester/config.py <==
from authomatic.providers import oauth2, oauth1
import authomatic

# Sample app for testing the Authomatic Python library.

CONFIG = {
    
    #===========================================================================
    # OAuth 2.0
    #===========================================================================
    
    'behance': {
         'class_': oauth2.Behance,
         'consumer_key': '9Y3MqHTzInJtTxg7Cq2m7UgZoObvVAfv',
         'consumer_secret': '8PSBWI_o3MYtWvd0MjdV0ISFGsWbsDvH',
         'offline': True,
         'scope': oauth2.Behance.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'bitly': {
         'class_': oauth2.Bitly,
         'consumer_key': 'd4afbd49a8abfbbf288730725dd9609dbb167320',
         'consumer_secret': 'cd30cb160445410d2825aed974ae5fdb15a3db9b',
         'offline': True,
         'scope': oauth2.Bitly.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'cosm': {
         'class_': oauth2.Cosm,
         'consumer_key': 'c1234a3ec89a040ed28c',
         'consumer_secret': 'Wv3CNrq-0Psk7hLNec67f3FjM1KKTmv8Z9jj6kjdb8fPvBtw',
         'offline': True,
         'scope': oauth2.Cosm.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'deviantart': {
         'class_': oauth2.DeviantART,
         'consumer_key': '376',
         'consumer_secret': 'd56ec842a9558fe9916210b376988c2d',
         'offline': True,
         'scope': oauth2.DeviantART.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'facebook': {
           
           'class_': oauth2.Facebook,
           'consumer_key': '482771598445314',
           'consumer_secret': '7163e6e8dedc2c055445b553823ec910',
           'offline': True,
           'scope': oauth2.Facebook.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'foursquare': {
           
           'class_': oauth2.Foursquare,
           'consumer_key': '11Q4GU3IGQYN3QTR5542VAGE1ZCQD5QDAOXVR1LA3FZ3Q24Z',
           'consumer_secret': 'WN1HYN4W0QJ4H0YV2KET1XKJHA1W2PFQT4WFOKDG3J3T05GK',
           'offline': True,
           'scope': oauth2.Foursquare.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'github': {
           
           'class_': oauth2.GitHub,
           'consumer_key': 'c6626326556058c8b4e6',
           'consumer_secret': '10a414828680701bd4005d3f67510e1d8864c3dd',
           'offline': True,
           'scope': oauth2.GitHub.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'google': {
         'class_': oauth2.Google,
         'consumer_key': '75167970188.apps.googleusercontent.com',
         'consumer_secret': 'Y70ZmvlkMKOTB8kKGBgN_BME',
         'offline': True,
         'scope': oauth2.Google.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'linkedin': {
         'class_': oauth2.LinkedIn,
         'consumer_key': 'idrh3rkqtgxe',
         'consumer_secret': 'vtae4fUc1plDjPLc',
         'offline': True,
         'scope': oauth2.LinkedIn.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'paypal': {
         'class_': oauth2.PayPal,
         'consumer_key': 'AR58GRBgr81q6vZQOUxwB1OF9_62PXb1CouQVaENf5dbTLgPkr3K7YZXgnc6',
         'consumer_secret': 'EJqCvRAZ4sFobX_NlzyVMyD3PSXH41pAWpeCFpiepworglq_f_5dl3TrCYFl',
         'offline': True,
         'scope': oauth2.PayPal.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'reddit': {
         'class_': oauth2.Reddit,
         'consumer_key': 'sodaC5hCCS-QHA',
         'consumer_secret': 'zBevflb04ncHRYbbG8ZAfQoy9T8',
         'offline': True,
         'scope': oauth2.Reddit.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'viadeo': {
         'class_': oauth2.Viadeo,
         'consumer_key': 'AuthomaticDevNyWlGx',
         'consumer_secret': 'NvQuiowaMRBcs',
         'offline': True,
         'scope': oauth2.Viadeo.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'vk': {
         'class_': oauth2.VK,
         'consumer_key': '3479081',
         'consumer_secret': '3QKH4U5tpKytUYDGMWbO',
         'offline': True,
         'scope': oauth2.VK.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'windows_live': {
         'class_': oauth2.WindowsLive,
         'consumer_key': '00000000440E8C5B',
         'consumer_secret': 'gu57AluGQnMkzxzdVp0ficFC00pBkl4S',
         'offline': True,
         'scope': oauth2.WindowsLive.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'yammer': {
         'class_': oauth2.Yammer,
         'consumer_key': '9JsB3qvVnptaR8GOkfA',
         'consumer_secret': 'Rt11EFemrHIZ6VY8pk8K4CvovTM6Y4hQmo8E3HDKY',
         'offline': True,
         'scope': oauth2.Yammer.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'yandex': {
         'class_': oauth2.Yandex,
         'consumer_key': '9c77329488b24bc6b8edb66777e1236a',
         'consumer_secret': '4b4408cda2f0459fab278b0880ebcf4d',
         'offline': True,
         'scope': oauth2.Yandex.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    #===========================================================================
    # Oauth 1.0a
    #===========================================================================
    
    'bitbucket': {
           'class_': oauth1.Bitbucket,
           'consumer_key': 'pusFTPPcYe7UjdPLeb',
           'consumer_secret': 'xHMUxrqZqM2bZ7UPdu85y2fyffYsKJzq',
         'id': authomatic.provider_id(),
    },
    
    'flickr': {
           'class_': oauth1.Flickr,
           'consumer_key': '518b447b07302e1a96cd0c4db9ae7580',
           'consumer_secret': 'b9b34d4b31d98b3d',
         'id': authomatic.provider_id(),
    },
    
    'meetup': {
         'class_': oauth1.Meetup,
         'consumer_key': 'lv335k1upsandlt8ohvdq857b9',
         'consumer_secret': 'asaljb9s015pik7uspkfki1dja',
         'id': authomatic.provider_id(),
    },
    
    'plurk': {
           'class_': oauth1.Plurk,
           'consumer_key': 'hx3idQuoDcyo',
           'consumer_secret': 'pXaLo11CSa39WVYbC39bksvXhfVHDZyf',
         'id': authomatic.provider_id(),
    },
    
    'twitter': {
           'class_': oauth1.Twitter,
           'consumer_key': 'zku3BZ9wi7e4e07h0M3VA',
           'consumer_secret': 'WQ0SYSUWXlBiLvYAJ32DDMfwsJ4up79EfifNXks',
         'id': authomatic.provider_id(),
    },
    
    'tumblr': {
           'class_': oauth1.Tumblr,
           'consumer_key': 'WKEotHgVxt9TK3Vh9HjRKRhz1ZUXkHIVuwc7rR8O9phG39TzxI',
           'consumer_secret': 'rZqq5XMtTjBRbX9wAMJ1j9W1EIUCgx5g2J7KCiDtu3jBv0XQUi',
         'id': authomatic.provider_id(),
    },
    
    'ubuntuone': {
           'class_': oauth1.UbuntuOne,
           'consumer_key': 'ubuntuone',
           'consumer_secret': 'hammertime',
         'id': authomatic.provider_id(),
    },
    
    'vimeo': {
           'class_': oauth1.Vimeo,
           'consumer_key': 'd8950e8cffe196c1feaeb4b5ac0d0243bdaf251a',
           'consumer_secret': 'a6f17a979fa0e55420365bea90375a4e3f1a862d',
         'id': authomatic.provider_id(),
    },
    
    'xero': {
           'class_': oauth1.Xero,
           'consumer_key': 'VR0V55UN8T8DHLMLWZB6AZYXTDHLAE',
           'consumer_secret': 'DLDNSTGEBVH4DPJTFEQVMZWRSU0P3O',
         'id': authomatic.provider_id(),
    },
    
    'yahoo': {
           'class_': oauth1.Yahoo,
           'consumer_key': 'dj0yJmk9ckppS2FnSVBBckswJmQ9WVdrOVlrZFdiVzVCTkdNbWNHbzlNVE16TVRFNU5ERTJNZy0tJnM9Y29uc3VtZXJzZWNyZXQmeD0xZg--',
           'consumer_secret': '933aab2e4009eef1c3820b2550e8af9f1dc50d30',
         'id': authomatic.provider_id(),
    },
}

==> Authomatic-0.0.7.tar.gz: Authomatic-0.0.7/examples/gae/tester/config.py <==
from authomatic.providers import oauth2, oauth1
import authomatic

# Sample app for testing the Authomatic Python library.

CONFIG = {
    
    #===========================================================================
    # OAuth 2.0
    #===========================================================================
    
    'behance': {
         'class_': oauth2.Behance,
         'consumer_key': '9Y3MqHTzInJtTxg7Cq2m7UgZoObvVAfv',
         'consumer_secret': '8PSBWI_o3MYtWvd0MjdV0ISFGsWbsDvH',
         'offline': True,
         'scope': oauth2.Behance.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'bitly': {
         'class_': oauth2.Bitly,
         'consumer_key': 'd4afbd49a8abfbbf288730725dd9609dbb167320',
         'consumer_secret': 'cd30cb160445410d2825aed974ae5fdb15a3db9b',
         'offline': True,
         'scope': oauth2.Bitly.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'cosm': {
         'class_': oauth2.Cosm,
         'consumer_key': 'c1234a3ec89a040ed28c',
         'consumer_secret': 'Wv3CNrq-0Psk7hLNec67f3FjM1KKTmv8Z9jj6kjdb8fPvBtw',
         'offline': True,
         'scope': oauth2.Cosm.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    'deviantart': {
         'class_': oauth2.DeviantART,
         'consumer_key': '376',
         'consumer_secret': 'd56ec842a9558fe9916210b376988c2d',
         'offline': True,
         'scope': oauth2.DeviantART.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'facebook': {
           
           'class_': oauth2.Facebook,
           'consumer_key': '482771598445314',
           'consumer_secret': '7163e6e8dedc2c055445b553823ec910',
           'offline': True,
           'scope': oauth2.Facebook.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'foursquare': {
           
           'class_': oauth2.Foursquare,
           'consumer_key': '11Q4GU3IGQYN3QTR5542VAGE1ZCQD5QDAOXVR1LA3FZ3Q24Z',
           'consumer_secret': 'WN1HYN4W0QJ4H0YV2KET1XKJHA1W2PFQT4WFOKDG3J3T05GK',
           'offline': True,
           'scope': oauth2.Foursquare.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'github': {
           
           'class_': oauth2.GitHub,
           'consumer_key': 'c6626326556058c8b4e6',
           'consumer_secret': '10a414828680701bd4005d3f67510e1d8864c3dd',
           'offline': True,
           'scope': oauth2.GitHub.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'google': {
         'class_': oauth2.Google,
         'consumer_key': '75167970188.apps.googleusercontent.com',
         'consumer_secret': 'Y70ZmvlkMKOTB8kKGBgN_BME',
         'offline': True,
         'scope': oauth2.Google.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'linkedin': {
         'class_': oauth2.LinkedIn,
         'consumer_key': 'idrh3rkqtgxe',
         'consumer_secret': 'vtae4fUc1plDjPLc',
         'offline': True,
         'scope': oauth2.LinkedIn.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'paypal': {
         'class_': oauth2.PayPal,
         'consumer_key': 'AR58GRBgr81q6vZQOUxwB1OF9_62PXb1CouQVaENf5dbTLgPkr3K7YZXgnc6',
         'consumer_secret': 'EJqCvRAZ4sFobX_NlzyVMyD3PSXH41pAWpeCFpiepworglq_f_5dl3TrCYFl',
         'offline': True,
         'scope': oauth2.PayPal.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'reddit': {
         'class_': oauth2.Reddit,
         'consumer_key': 'sodaC5hCCS-QHA',
         'consumer_secret': 'zBevflb04ncHRYbbG8ZAfQoy9T8',
         'offline': True,
         'scope': oauth2.Reddit.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'viadeo': {
         'class_': oauth2.Viadeo,
         'consumer_key': 'AuthomaticDevNyWlGx',
         'consumer_secret': 'NvQuiowaMRBcs',
         'offline': True,
         'scope': oauth2.Viadeo.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'vk': {
         'class_': oauth2.VK,
         'consumer_key': '3479081',
         'consumer_secret': '3QKH4U5tpKytUYDGMWbO',
         'offline': True,
         'scope': oauth2.VK.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'windows_live': {
         'class_': oauth2.WindowsLive,
         'consumer_key': '00000000440E8C5B',
         'consumer_secret': 'gu57AluGQnMkzxzdVp0ficFC00pBkl4S',
         'offline': True,
         'scope': oauth2.WindowsLive.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'yammer': {
         'class_': oauth2.Yammer,
         'consumer_key': '9JsB3qvVnptaR8GOkfA',
         'consumer_secret': 'Rt11EFemrHIZ6VY8pk8K4CvovTM6Y4hQmo8E3HDKY',
         'offline': True,
         'scope': oauth2.Yammer.user_info_scope,
         'id': authomatic.provider_id(),
    },
    
    'yandex': {
         'class_': oauth2.Yandex,
         'consumer_key': '9c77329488b24bc6b8edb66777e1236a',
         'consumer_secret': '4b4408cda2f0459fab278b0880ebcf4d',
         'offline': True,
         'scope': oauth2.Yandex.user_info_scope,
         'id': authomatic.provider_id(),
    },
          
    #===========================================================================
    # Oauth 1.0a
    #===========================================================================
    
    'bitbucket': {
           'class_': oauth1.Bitbucket,
           'consumer_key': 'pusFTPPcYe7UjdPLeb',
           'consumer_secret': 'xHMUxrqZqM2bZ7UPdu85y2fyffYsKJzq',
         'id': authomatic.provider_id(),
    },
    
    'flickr': {
           'class_': oauth1.Flickr,
           'consumer_key': '518b447b07302e1a96cd0c4db9ae7580',
           'consumer_secret': 'b9b34d4b31d98b3d',
         'id': authomatic.provider_id(),
    },
    
    'meetup': {
         'class_': oauth1.Meetup,
         'consumer_key': 'lv335k1upsandlt8ohvdq857b9',
         'consumer_secret': 'asaljb9s015pik7uspkfki1dja',
         'id': authomatic.provider_id(),
    },
    
    'plurk': {
           'class_': oauth1.Plurk,
           'consumer_key': 'hx3idQuoDcyo',
           'consumer_secret': 'pXaLo11CSa39WVYbC39bksvXhfVHDZyf',
         'id': authomatic.provider_id(),
    },
    
    'twitter': {
           'class_': oauth1.Twitter,
           'consumer_key': 'zku3BZ9wi7e4e07h0M3VA',
           'consumer_secret': 'WQ0SYSUWXlBiLvYAJ32DDMfwsJ4up79EfifNXks',
         'id': authomatic.provider_id(),
    },
    
    'tumblr': {
           'class_': oauth1.Tumblr,
           'consumer_key': 'WKEotHgVxt9TK3Vh9HjRKRhz1ZUXkHIVuwc7rR8O9phG39TzxI',
           'consumer_secret': 'rZqq5XMtTjBRbX9wAMJ1j9W1EIUCgx5g2J7KCiDtu3jBv0XQUi',
         'id': authomatic.provider_id(),
    },
    
    'ubuntuone': {
           'class_': oauth1.UbuntuOne,
           'consumer_key': 'ubuntuone',
           'consumer_secret': 'hammertime',
         'id': authomatic.provider_id(),
    },
    
    'vimeo': {
           'class_': oauth1.Vimeo,
           'consumer_key': 'd8950e8cffe196c1feaeb4b5ac0d0243bdaf251a',
           'consumer_secret': 'a6f17a979fa0e55420365bea90375a4e3f1a862d',
         'id': authomatic.provider_id(),
    },
    
    'xero': {
           'class_': oauth1.Xero,
           'consumer_key': 'VR0V55UN8T8DHLMLWZB6AZYXTDHLAE',
           'consumer_secret': 'DLDNSTGEBVH4DPJTFEQVMZWRSU0P3O',
         'id': authomatic.provider_id(),
    },
    
    'yahoo': {
           'class_': oauth1.Yahoo,
           'consumer_key': 'dj0yJmk9cU1wQ3N2aTFlYzlXJmQ9WVdrOVlrZFdiVzVCTkdNbWNHbzlNVE16TVRFNU5ERTJNZy0tJnM9Y29uc3VtZXJzZWNyZXQmeD03Mw--',
           'consumer_secret': '41cb637f38ff5225a20f4e2b9c321eb96cdea6ee',
         'id': authomatic.provider_id(),
    },
}
